class NoiseEngine:
    def __init__(self, seed: float = 0.5):
        self.x = seed

    def drift(self) -> float:
        """
        Generates chaotic drift using Logistic Map.
        """
        r = 3.99
        self.x = r * self.x * (1 - self.x)
        return self.x * 0.1
